<?php
/*
Plugin Name: UpiCRM Facebook
Text Domain: upicrm
Domain Path: /languages
Plugin URI: http://www.upicrm.com?utm_source=plpage
Description: UpiCRM is a universal WordPress CRM solution can interface and extend the most popular WordPress contact forms plugins, and provide a complete CRM solution

Version: 1.0.5
*/

define('DISABLE_WP_CRON', false);

function upicrmfb_db() {
    global $wpdb;
    return $wpdb->prefix."upicrm_fb_";
}

$SourceTypeID['fb_lead'] = 101;
$SourceTypeName[101] = "Facebook Lead";

/** Setup */
require_once( plugin_dir_path( __FILE__ ) . 'setup.php' );
register_activation_hook(__FILE__,'upicrmfb_setup_plugin');
add_action( 'plugins_loaded', 'upicrmfb_update_db_check' );

require_once(dirname(__FILE__) . '/Facebook/autoload.php');

require_once( plugin_dir_path( __FILE__ ) . 'functions.php' );

/* Classes */
require_once( plugin_dir_path( __FILE__ ) . 'classes/conf_class.php' );
require_once( plugin_dir_path( __FILE__ ) . 'classes/form_class.php' );
/*require_once( plugin_dir_path( __FILE__ ) . 'classes/fields_class.php' );
require_once( plugin_dir_path( __FILE__ ) . 'classes/upicrm_integration_class.php' );*/

/** Libraries */
require_once( plugin_dir_path( __FILE__ ) . 'libraries/get_leads.php' );
require_once( plugin_dir_path( __FILE__ ) . 'libraries/activation.php' );



if ( is_admin() ) {
    /* Admins files */
    require_once( plugin_dir_path( __FILE__ ) . 'admin/main.php' );
    require_once( plugin_dir_path( __FILE__ ) . 'admin/map_fields.php' );

    $UpiCRMAdminFB= new UpiCRMAdminFB();
    
    wp_register_style( 'upicrm_fb_css', plugin_dir_url(dirname(__FILE__)).trailingslashit(dirname(plugin_basename(__FILE__))).'css/style.css', FALSE, '0.1' );
    wp_enqueue_style( 'upicrm_fb_css' );

}

class UpiCRMAdminFB {
    public function __construct() {
        add_action('admin_menu', array($this, 'onWpAdminMenu'));
    }
    function onWpAdminMenu() {
        add_submenu_page('upicrm_index', __('Facebook Integration', 'upicrm_fb'), __('Facebook Integration', 'upicrm_fb'), 'read', 'upicrm_fb', array( $this, 'onDisplayMain'));
        add_submenu_page( 'upicrm_dont_show', '', __('Facebook Integration Map Fields', 'upicrm_fb'), 'read', 'upicrm_fb_map_fields', array( $this, 'onDisplayMapFields' ) );
        add_submenu_page( 'upicrm_dont_show', '', __('Facebook Integration Map Fields', 'upicrm_fb'), 'read', 'upicrm_fb_test', array( $this, 'test' ) );
        
    }
    
    function onDisplayMain() {
        $this->checkActivation();
        $UpiCRMAdminWarp = new UpiCRMAdminWarp();
        $upi_setting['title'] = __('Facebook Integration', 'upicrm_fb');
        $upi_setting['logo'] = 'file-excel-o';
        $UpiCRMAdminWarp->header($upi_setting);
        $UpiCRMFBIndex = new UpiCRMFBIndex();
        $UpiCRMFBIndex->render();
        $UpiCRMAdminWarp->footer();
    }
    
    function onDisplayMapFields() {
        $this->checkActivation();
        $UpiCRMAdminWarp = new UpiCRMAdminWarp();
        $upi_setting['title'] = '<a href="admin.php?page=upicrm_fb">'.__('Facebook Integration', 'upicrm_gs').'</a> > '.__('Form setting and fields mapping', 'upicrm_gs');
        $upi_setting['logo'] = 'cogs';
        $UpiCRMAdminWarp->header($upi_setting);
        $UpiCRMAFBMapFields = new UpiCRMAFBMapFields();
        $UpiCRMAFBMapFields->render();
        $UpiCRMAdminWarp->footer();
    }
    
    function checkActivation() {
        if (get_option('upicrmfb_activation_status') != 1) {
            include_once upicrmfb_template('main/activation');
        }
    }
    
}

//use this for debug like this: admin.php?upicrmgs_get_action=get_sheet
if (isset($_GET['upicrmfb_debug'])) {
    $UpiCRMFB_get_leads = new UpiCRMFB_get_leads();
    $UpiCRMFB_get_leads->save_lead();
    die();
}

add_action('admin_init', 'upicrmfb_setup_redirect');
function upicrmfb_setup_redirect() {
    if (get_option('upicrmfb_activation_redirect', false)) {
        delete_option('upicrmfb_activation_redirect');
         exit( wp_redirect("admin.php?page=upicrm_fb") );
    }
}

function upicrmfb_cron_time_settings() {
	register_setting( 'upicrmfb-mf-settings-group', 'upicrmfb_cron_time' );
}
add_action( 'admin_init', 'upicrmfb_cron_time_settings' );

/* CRON JOB */

// Adding A New Schedule
add_filter('cron_schedules', 'upicrmfb_cron_new_schedule');
function upicrmfb_cron_new_schedule($array) {
    $minutes = intval( get_option('upicrmfb_cron_time', 60) );
    $seconds = 60 * $minutes;
    $array['upicrmfb_set_cron_time'] = array(
        'interval' => $seconds,
        'display'  => __( 'Every '.$minutes.' Minutes' )
    );
    return $array;
}

if (!wp_next_scheduled('upicrmfb_cron_event')) {
    wp_schedule_event(time(), 'upicrmfb_set_cron_time', 'upicrmfb_cron_event');
}

add_action('upicrmfb_cron_event', 'upicrmfb_run_cron_job');

function upicrmfb_run_cron_job() {
    $UpiCRMFB_get_leads = new UpiCRMFB_get_leads();
    $UpiCRMFB_get_leads->save_lead();
    die();
}
?>